==> rawkit-1.2.1.tgz: app.js <==
/* global chrome */

function isCore (url) {
  return -~url.indexOf('chrome://') || -~url.indexOf('chrome-devtools://')
}

function parse (url) {
  var matches = url.match(/rawkit=([^&#=]*)/gi)
  return (matches) ? matches[0].replace('rawkit=', '') : null
}

chrome.browserAction.onClicked.addListener(function (tab) {
  chrome.tabs.create({ url: 'chrome-devtools://devtools/bundled/inspector.html?nodeFrontend=true&v8only=true&dockSide=undocked&experiments=true' })
})

chrome.runtime.onInstalled.addListener(function () {
  chrome.tabs.query({ url: '*://darcyclarke.github.io/rawkit/*' }, function (tabs) {
    if(tabs.length >= 1) {
      for (let i = tabs.length - 1; i >= 0; i--) {
        chrome.tabs.update(tabs[i].id, { url: decodeURIComponent(tabs[i].url) })
      }
    }
  })
})

chrome.tabs.onCreated.addListener(function () {
  chrome.tabs.query({ 'active': true, 'lastFocusedWindow': true }, function (tabs) {
    var url = tabs[0].url
    var link = parse(url)
    var parent = tabs[0].id
    if (!isCore(url) && link) {
      chrome.tabs.query({}, function (tabs) {
        let id = null
        for (let i = chrome.tabs.length - 1; i >= 0; i--) {
          if (tabs[i].url === url) {
            id = tabs[i].id
            break
          }
        }
        if (!id) {
          chrome.tabs.update(parent, { url: decodeURIComponent(link) })
        } else {
          chrome.tabs.update(id, { selected: true })
        }
      })
    }
  })
})

// window.addEventListener('load', function () {})

==> rawkit-1.3.0.tgz: app.js <==
/* global chrome */

function isCore (url) {
  return -~url.indexOf('chrome://') || -~url.indexOf('chrome-devtools://')
}

function parse (url) {
  var matches = url.match(/rawkit=([^&#=]*)/gi)
  return (matches) ? matches[0].replace('rawkit=', '') : null
}

chrome.browserAction.onClicked.addListener(function (tab) {
  chrome.tabs.create({ url: 'chrome-devtools://devtools/bundled/inspector.html?nodeFrontend=true&v8only=true&dockSide=undocked&experiments=true' })
})

chrome.runtime.onInstalled.addListener(function () {
  chrome.tabs.query({ url: '*://darcyclarke.github.io/rawkit/*' }, function (tabs) {
    if (tabs.length >= 1) {
      for (let i = tabs.length - 1; i >= 0; i--) {
        var link = parse(tabs[i].url)
        chrome.tabs.update(tabs[i].id, { url: decodeURIComponent(link) })
      }
    }
  })
})

chrome.tabs.onCreated.addListener(function () {
  chrome.tabs.query({ 'active': true, 'lastFocusedWindow': true }, function (tabs) {
    var url = tabs[0].url
    var link = parse(url)
    var parent = tabs[0].id
    if (!isCore(url) && link) {
      chrome.tabs.query({}, function (tabs) {
        let id = null
        for (let i = chrome.tabs.length - 1; i >= 0; i--) {
          if (tabs[i].url === url) {
            id = tabs[i].id
            break
          }
        }
        if (!id) {
          chrome.tabs.update(parent, { url: decodeURIComponent(link) })
        } else {
          chrome.tabs.update(id, { selected: true })
        }
      })
    }
  })
})

// window.addEventListener('load', function () {})
